@@ -177,6 +177,9 @@
 #define MSG_NOT_FILE _("Is '%s' a file?")
 #define MSG_INTERFACE_NOT_FOUND _("Failed to find given interface %s,"\
 				  " cause: %s")
+#define MSG_METADATA_SAVED _("Saved metadata as %s.")
+#define MSG_METADATA_NOT_SAVED _("Saving metadata as %s failed. Maybe file"\
+				 " already exists.")
 
 #define EX_TIME_OUT _("Timeout.")
 #define EX_INVALID_CHUNK_SIZE _("Invalid chunk size.")
